@@ -1,5 +1,5 @@
 package Sisimai::DateTime;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 use Time::Piece;
@@ -443,7 +443,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2023 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
