@@ -1,16 +1,16 @@
 package Sisimai::Lhost::Barracuda;
 use parent 'Sisimai::Lhost';
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
 sub description { 'Barracuda: https://www.barracuda.com' }
-sub make {
+sub inquire {
     # Detect an error from Barracuda
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [Undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to parse or the arguments are missing
     # @since v4.25.6
     my $class = shift;
     my $mhead = shift // return undef;
@@ -20,22 +20,21 @@ sub make {
     return undef unless index($mhead->{'subject'}, 'our bulk email filter') > 0;
 
     state $indicators = __PACKAGE__->INDICATORS;
-    state $rebackbone = qr|^Content-Type:[ ]text/rfc822-headers|m;
+    state $boundaries = ['Content-Type: text/rfc822-headers'];
     state $startingof = { 'message' => ['Your message to:'] };
 
-    require Sisimai::RFC1894;
     my $fieldtable = Sisimai::RFC1894->FIELDTABLE;
     my $permessage = {};    # (Hash) Store values of each Per-Message field
 
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $rebackbone);
+    my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $v = undef;
 
-    for my $e ( split("\n", $emailsteak->[0]) ) {
-        # Read error messages and delivery status lines from the head of the email
-        # to the previous line of the beginning of the original message.
+    for my $e ( split("\n", $emailparts->[0]) ) {
+        # Read error messages and delivery status lines from the head of the email to the previous
+        # line of the beginning of the original message.
         unless( $readcursor ) {
             # Beginning of the bounce message or message/delivery-status part
             $readcursor |= $indicators->{'deliverystatus'} if index($e, $startingof->{'message'}->[0]) == 0;
@@ -87,7 +86,7 @@ sub make {
         $e->{ $_ } ||= $permessage->{ $_ } || '' for keys %$permessage;
         $e->{'diagnosis'} ||= Sisimai::String->sweep($e->{'diagnosis'});
     }
-    return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
+    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
 }
 
 1;
@@ -105,8 +104,8 @@ Sisimai::Lhost::Barracuda - bounce mail parser class for C<Barracuda>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::Barracuda parses a bounce email which created by C<Barracuda>.
-Methods in the module are called from only Sisimai::Message.
+Sisimai::Lhost::Barracuda parses a bounce email which created by C<Barracuda>. Methods in the module
+are called from only Sisimai::Message.
 
 =head1 CLASS METHODS
 
@@ -116,10 +115,10 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::Barracuda->description;
 
-=head2 C<B<make(I<header data>, I<reference to body string>)>>
+=head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<make()> method parses a bounced email and return results as a array reference.
-See Sisimai::Message for more details.
+C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
+for more details.
 
 =head1 AUTHOR
 
@@ -127,7 +126,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2020,2021,2023,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
