@@ -1,6 +1,6 @@
 package Sisimai::Lhost::Domino;
 use parent 'Sisimai::Lhost';
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 use Sisimai::String;
