@@ -1,6 +1,6 @@
 package Sisimai::Lhost::MailMarshalSMTP;
 use parent 'Sisimai::Lhost';
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -161,7 +161,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2021,2023 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2021,2023,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
