@@ -1,5 +1,5 @@
 package Sisimai::MDA;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -177,7 +177,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018-2023 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018-2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
