@@ -1,5 +1,5 @@
 package Sisimai::Mail::Mbox;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 use File::Basename qw(basename dirname);
@@ -127,8 +127,8 @@ C<size()> returns the file size of the mbox.
 
 =head2 C<B<offset()>>
 
-C<offset()> returns offset position for seeking the mbox. The value of "offset"
-is bytes which have already read.
+C<offset()> returns offset position for seeking the mbox. The value of "offset" is bytes which have
+already read.
 
     print $mailbox->offset;   # 0
 
@@ -153,7 +153,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018,2019 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2019,2021,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
