@@ -1,5 +1,5 @@
 package Sisimai::Mail::STDIN;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 use IO::Handle;
@@ -120,7 +120,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018-2021 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018-2021,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
