@@ -1,5 +1,5 @@
 package Sisimai::RFC1894;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -230,7 +230,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2018-2023 azumakuniyuki, All rights reserved.
+Copyright (C) 2018-2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
