@@ -1,5 +1,5 @@
 package Sisimai::RFC3464;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 use Sisimai::Lhost;
@@ -436,7 +436,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2023 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
