@@ -1,5 +1,5 @@
 package Sisimai::Reason::ContentError;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -15,6 +15,8 @@ sub match {
     my $argv1 = shift // return undef;
 
     state $index = [
+        'duplicate header',
+        'header size exceeds maximum permitted',
         'improper use of 8-bit data in message header',
         'message header size, or recipient list, exceeds policy limit',
         'message mime complexity exceeds the policy maximum',
@@ -29,7 +31,7 @@ sub match {
 
 sub true {
     # Rejected email due to header format of the email
-    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @param    [Sisimai::Fact] argvs   Object to be detected the reason
     # @return   [Integer]               1: rejected due to content error
     #                                   0: is not content error
     # @see      http://www.ietf.org/rfc/rfc2822.txt
@@ -52,19 +54,18 @@ Sisimai::Reason::ContentError - Bounce reason is C<contenterror> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::ContentError checks the bounce reason is C<contenterror> or not.
-This class is called only Sisimai::Reason class.
+Sisimai::Reason::ContentError checks the bounce reason is C<contenterror> or not. This class is called
+only Sisimai::Reason class.
 
-This is the error that a destination mail server has rejected email due to
-header format of the email like the following. Sisimai will set C<contenterror>
-to the reason of email bounce if the value of Status: field in a bounce email
-is "5.6.*".
+This is the error that a destination mail server has rejected email due to header format of the email
+like the following. Sisimai will set C<contenterror> to the reason of email bounce if the value of
+Status: field in a bounce email is "5.6.*".
 
 =over
 
 =item - 8 bit data in message header
 
-=item - Too many “Received” headers
+=item - Too many "Received" headers
 
 =item - Invalid MIME headers
 
@@ -89,10 +90,10 @@ C<match()> returns 1 if the argument matched with patterns defined in this class
 
     print Sisimai::Reason::ContentError->match('550 Message Filterd'); # 1
 
-=head2 C<B<true(I<Sisimai::Data>)>>
+=head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<contenterror>. The argument must be
-Sisimai::Data object and this method is called only from Sisimai::Reason class.
+C<true()> returns 1 if the bounce reason is C<contenterror>. The argument must be Sisimai::Fact object
+and this method is called only from Sisimai::Reason class.
 
 =head1 AUTHOR
 
@@ -100,7 +101,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2021,2022,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
