@@ -1,5 +1,5 @@
 package Sisimai::Reason::Feedback;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -49,7 +49,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016,2021 azumakuniyuki, All rights reserved.
+Copyright (C) 2016,2021,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
