@@ -1,5 +1,5 @@
 package Sisimai::Reason::HostUnknown;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 use Sisimai::String;
@@ -120,7 +120,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2018,2020,2021,2023 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018,2020,2021,2023,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
