@@ -1,5 +1,5 @@
 package Sisimai::Reason::MailboxFull;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -15,6 +15,7 @@ sub match {
     my $argv1 = shift // return undef;
 
     state $index = [
+        '452 insufficient disk space',
         'account disabled temporarly for exceeding receiving limits',
         'account is exceeding their quota',
         'account is over quota',
@@ -42,7 +43,9 @@ sub match {
         'maildir delivery failed: userdisk quota ',
         'maildir delivery failed: domaindisk quota ',
         'mailfolder is full',
+        'no space left on device',
         'not enough storage space in',
+        'not sufficient disk space',
         'over the allowed quota',
         'quota exceeded',
         'quota violation for',
