@@ -1,7 +1,8 @@
 package Sisimai::Reason::PolicyViolation;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
+use Sisimai::String;
 
 sub text  { 'policyviolation' }
 sub description { 'Email rejected due to policy violation on a destination host' }
@@ -20,7 +21,6 @@ sub match {
         'by non-member to a members-only list',
         'closed mailing list',
         'denied by policy',
-        'dmarc policy',
         'email not accepted for policy reasons',
         # http://kb.mimecast.com/Mimecast_Knowledge_Base/Administration_Console/Monitoring/Mimecast_SMTP_Error_Codes#554
         'email rejected due to security policies',
@@ -30,22 +30,27 @@ sub match {
         'message bounced due to organizational settings',
         'message given low priority',
         'message not accepted for policy reasons',
+        'message rejected due to local policy',
         'messages with multiple addresses',
         'rejected for policy reasons',
         'protocol violation',
         'the email address used to send your message is not subscribed to this group',
+        'the message was rejected by organization policy',
         'this message was blocked because its content presents a potential',
         'we do not accept messages containing images or other attachments',
-        'you have exceeded the allowable number of posts without solving a captcha',
-        'you have exceeded the the allowable number of posts without solving a captcha',
+        "you're using a mass mailer",
+    ];
+    state $pairs = [
+        ['you have exceeded the', 'allowable number of posts without solving a captcha'],
     ];
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
+    return 1 if grep { Sisimai::String->aligned(\$argv1, $_) } @$pairs;
     return 0;
 }
 
 sub true {
     # The bounce reason is "policyviolation" or not
-    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @param    [Sisimai::Fact] argvs   Object to be detected the reason
     # @return   [Integer]               1: is policy violation
     #                                   0: is not policyviolation
     # @since v4.22.0
@@ -69,12 +74,12 @@ Sisimai::Reason::PolicyViolation - Bounce reason is C<policyviolation> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::PolicyViolation checks the bounce reason is C<policyviolation>
-or not. This class is called only Sisimai::Reason class.
+Sisimai::Reason::PolicyViolation checks the bounce reason is C<policyviolation> or not. This class
+is called only Sisimai::Reason class.
 
-This is the error that a policy violation was detected on a destination mail host.
-When a header content or a format of the original message violates security policies,
-or multiple addresses exist in the From: header, Sisimai will set C<policyviolation>.
+This is the error that a policy violation was detected on a destination mail host. When a header
+content or a format of the original message violates security policies, or multiple addresses exist
+in the From: header, Sisimai will set C<policyviolation>.
 
     Action: failed
     Status: 5.7.0
@@ -96,10 +101,10 @@ C<match()> returns 1 if the argument matched with patterns defined in this class
 
     print Sisimai::Reason::PolicyViolation->match('5.7.9 Header error');    # 1
 
-=head2 C<B<true(I<Sisimai::Data>)>>
+=head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<policyviolation>. The argument must be
-Sisimai::Data object and this method is called only from Sisimai::Reason class.
+C<true()> returns 1 if the bounce reason is C<policyviolation>. The argument must be Sisimai::Fact
+object and this method is called only from Sisimai::Reason class.
 
 =head1 AUTHOR
 
@@ -107,7 +112,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2017-2021 azumakuniyuki, All rights reserved.
+Copyright (C) 2017-2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
