@@ -1,5 +1,5 @@
 package Sisimai::Reason::SystemFull;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -78,7 +78,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018,2020,2021 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2020,2021,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
