@@ -1,5 +1,5 @@
 package Sisimai::Rhost::Cox;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -132,7 +132,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2020-2023 azumakuniyuki, All rights reserved.
+Copyright (C) 2020-2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
