@@ -1,5 +1,5 @@
 package Sisimai::Rhost::Google;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -26,16 +26,16 @@ sub get {
             # - 550 5.7.24 The SPF record of the sending domain has one or more suspicious entries.
             #   For more information, go to Email sender guidelines.
             # - https://support.google.com/mail/answer/81126#authentication
-            ['451', '4.7.24', 'the spf record of the sending domain has one or more suspicious entries'],
-            ['550', '5.7.24', 'the spf record of the sending domain has one or more suspicious entries'],
+            ['451', '4.7.24', 'the spf record of the sending domain'],
+            ['550', '5.7.24', 'the spf record of the sending domain'],
 
             # - 421 4.7.26 This mail has been rate limited because it is unauthenticated.
             #   Gmail requires all senders to authenticate with either SPF or DKIM.
             #   Authentication results: DKIM = did not pass SPF domain-name with ip: ip-address =
             #   did not pass. To resolve this issue, go to Email sender guidelines. 
             # - https://support.google.com/mail/answer/81126#authentication
-            ['421', '4.7.26', 'gmail requires all senders to authenticate with either spf or dkim'],
-            ['550', '5.7.26', 'gmail requires all senders to authenticate with either spf or dkim'],
+            ['421', '4.7.26', 'senders to authenticate with either spf or dkim'],
+            ['550', '5.7.26', 'senders to authenticate with either spf or dkim'],
 
             # - 550 5.7.26 This message fails to pass SPF checks for an SPF record with a hard fail
             #   policy (-all). To best protect our users from spam and phishing, the message has
@@ -47,7 +47,7 @@ sub get {
             #   protect our users from spam and phishing, the message has been blocked. For more
             #   information, go to Email sender guidelines.
             # - https://support.google.com/mail/answer/81126#authentication
-            ['550', '5.7.26', 'this message fails to pass spf checks for an spf record with a hard fail'],
+            ['550', '5.7.26', 'fails to pass spf checks for an spf record with a hard fail'],
             ['550', '5.7.26', 'has an spf record with a hard fail policy'],
 
             # - 451 4.7.26 Unauthenticated email from domain-name is not accepted due to domain's
@@ -72,40 +72,49 @@ sub get {
             ['550', '5.7.1',  'fails to pass authentication checks'],
             ['550', '5.7.26', 'fails to pass authentication checks'],
 
-            # - 421 4.7.27 This mail has been rate limited because SPF does not pass.
-            #   Gmail requires all large senders to authenticate with SPF. Authentication results:
-            #   SPF domain-name with ip: ip-address = did not pass. To resolve this issue, go to
-            #   Define your SPF record—Basic setup. https://support.google.com/a/answer/10685031
-            ['421', '4.7.27', 'gmail requires all large senders to authenticate with spf'],
-            ['550', '5.7.27', 'gmail requires all large senders to authenticate with spf'],
+            # - 421 4.7.27 Your email has been rate limited because SPF authentication didn't pass
+            #   for this message. Gmail requires all bulk email senders to authenticate their emaili
+            #   with SPF. Authentication results: SPF domain-name with IP address: ip-address = Did
+            #   not pass.
+            ['421', '4.7.27', 'senders to authenticate with spf'],
+            ['421', '4.7.27', 'senders to authenticate their email with spf'],
+            ['550', '5.7.27', 'senders to authenticate with spf'],
 
-            # - 421 4.7.28 This mail has been rate limited because DKIM does not pass.
-            #   Gmail requires all large senders to authenticate with DKIM. Authentication results:
-            #   DKIM = did not pass. For instructions on setting up DKIM authentication, go to Turn
-            #   on DKIM for your domain. https://support.google.com/a/answer/180504
-            ['421', '4.7.28', 'gmail requires all large senders to authenticate with dkim'],
-            ['550', '5.7.28', 'gmail requires all large senders to authenticate with dkim'],
+            # - 421 4.7.30 Your email has been rate limited because DKIM authentication didn't pass
+            #   for this message. Gmail requires all email bulk senders to authenticate their email
+            #   with DKIM. Authentication results: DKIM = Did not pass.
+            ['421', '4.7.30', 'senders to authenticate their email with dkim'],
+
+            # - 550 5.7.30 This mail has been blocked because DKIM does not pass. Gmail requires all
+            #   large senders to authenticate with DKIM. Authentication results: DKIM = did not pass.
+            #   For instructions on setting up DKIM authentication, go to Turn on DKIM for your domain.   
+            ['550', '5.7.30', 'senders to authenticate with dkim'],
+
+            # - 421 4.7.32 Your email has been rate limited because the From: header (RFC5322) in
+            #   this message isn't aligned with either the authenticated SPF or DKIM organizational
+            #   domain.
+            ['421', '4.7.32', 'aligned with either the authenticated spf or dkim'],
         ],
         'badreputation' => [
             # - 421 4.7.0 This message is suspicious due to the very low reputation of the sending
             #   IP address/domain. To protect our users from spam, mail sent from your IP address
             #   has been temporarily rate limited. For more information, go to Why has Gmail blocked
             #   my messages?. https://support.google.com/mail/answer/188131
-            ['421', '4.7.0', 'this message is suspicious due to the very low reputation of the sending ip address'],
-            ['421', '4.7.0', 'this message is suspicious due to the very low reputation of the sending domain'],
+            ['421', '4.7.0', 'very low reputation of the sending ip address'],
+            ['421', '4.7.0', 'very low reputation of the sending domain'],
 
             # - 550 5.7.1 Our system has detected that this message is likely suspicious due to the
             #   very low reputation of the sending IP address/domain. To best protect our users
             #   from spam, the message has been blocked. 
             #   Please visit https://support.google.com/mail/answer/188131 for more information.
-            ['550', '5.7.1', 'this message is likely suspicious due to the very low reputation of the sending ip address'],
-            ['550', '5.7.1', 'this message is likely suspicious due to the very low reputation of the sending domain'],
+            ['550', '5.7.1', 'due to the very low reputation of the sending ip address'],
+            ['550', '5.7.1', 'due to the very low reputation of the sending domain'],
         ],
         'blocked' => [
             # - 421 4.7.0 IP not in whitelist for RCPT domain, closing connection.
             #   For more information, go to Allowlists, denylists, and approved senders.
             #   https://support.google.com/a/answer/60752
-            ['421', '4.7.0', 'ip not in whitelist for rcpt domain, closing connection.'],
+            ['421', '4.7.0', 'ip not in whitelist for rcpt domain'],
 
             # - 421 4.7.0 Try again later, closing connection. This usually indicates a Denial of
             #   Service (DoS) for the SMTP relay at the HELO stage.
@@ -116,7 +125,7 @@ sub get {
             ['501', '5.5.4', 'empty helo/ehlo argument not allowed'],
             ['501', '5.5.4', 'helo/ehlo argument is invalid'],
 
-            # - 421 4.7.28 Gmail has detected an unusual rate of unsolicited mail.
+            # - 421 4.7.28 Gmail has detected an unusual rate of mail
             #   (originating from)
             #       - your IP address 192.0.2.25
             #       - your IP Netblock 192.0.2.0/24 (?)
@@ -128,7 +137,7 @@ sub get {
             #   our bulk email senders guidelines, go to Email sender guidelines.
             #   https://support.google.com/mail/?p=UnsolicitedRateLimitError
             ['421', '4.7.0',  'an unusual rate of unsolicited mail'],
-            ['421', '4.7.28', 'an unusual rate of unsolicited mail'],
+            ['421', '4.7.28', 'an unusual rate of mail'],
 
             # - 550 5.7.1 Our system has detected an unusual rate of unsolicited mail originating
             #   from your IP address. To protect our users from spam, mail sent from your IP ad-
@@ -137,13 +146,13 @@ sub get {
             # - 550 5.7.28 There is an unusual rate of unsolicited mail originating from your IP
             #   address. To protect our users from spam, mail sent from your IP address has been
             #   blocked. To review our bulk email senders guidelines, go to Email sender guidelines.
-            ['550', '5.7.1',  'an unusual rate of unsolicited mail originating from your ip address'],
-            ['550', '5.7.28', 'an unusual rate of unsolicited mail originating from your ip address'],
+            ['550', '5.7.1',  'an unusual rate of unsolicited mail'],
+            ['550', '5.7.28', 'an unusual rate of unsolicited mail'],
         ],
         'exceedlimit' => [
             # - 552 5.2.3 Your message exceeded Google's message size limits. For more information,
             #   visit https://support.google.com/mail/answer/6584
-            ['552', '5.2.3', "your message exceeded google's message size limits"],
+            ['552', '5.2.3', "exceeded google's message size limits"],
 
             # - 552 5.3.4 The number of attachments (num-attachments) exceeds Google's limit of
             #   limit attachments. To view our attachment size guidelines, go to Gmail receiving
@@ -155,8 +164,8 @@ sub get {
             ['552', '5.3.4', "exceeds google's limit of limit attachments."],
             ['552', '5.3.4', "your message exceeded google's message header size limits"],
             ['552', '5.3.4', 'bytes per individual header size'],
-            ['552', '5.3.4', "exceeds google’s header name limit of"],
-            ['552', '5.3.4', "your message has a subject: header that exceeds google's message header size limit"]
+            ['552', '5.3.4', "exceeds google's header name limit of"],
+            ['552', '5.3.4', "exceeds google's message header size limit"]
         ],
         'expired' => [
             # - 421 4.7.0 Connection expired, try reconnecting. For more information, go to About
@@ -176,15 +185,15 @@ sub get {
 
             # - 452 4.2.2 The email account that you tried to reach is over quota. Please direct
             #   the recipient to Clear Google Drive space & increase storage.
-            ['452', '4.2.2', 'the email account that you tried to reach is over quota'],
-            ['552', '5.2.2', 'the email account that you tried to reach is over quota'],
+            ['452', '4.2.2', 'is over quota'],
+            ['552', '5.2.2', 'is over quota'],
             ['550', '5.7.1', 'email quota exceeded'],
         ],
         'mesgtoobig' => [
             # - 552 5.3.4 Your message exceeded Google's message size limits. To view our message
             #   size guidelines, go to Send attachments with your Gmail message.
             # - https://support.google.com/mail/?p=MaxSizeError
-            ['552', '5.3.4', "your message exceeded google's message size limits"],
+            ['552', '5.3.4', "exceeded google's message size limits"],
 
             # - 552 5.3.4 The size of your message (size bytes) exceeded Google's message size
             #   limits of limit bytes. To view our message size guidelines, go to Gmail receiving
@@ -195,8 +204,8 @@ sub get {
         'networkerror' => [
             # - 554 5.4.6 Message exceeded 50 hops, this may indicate a mail loop.
             #   For more information, go to Gmail Help. https://support.google.com/mail/?p=MailLoop
-            ['554', '5.4.6', 'message exceeded 50 hops, this may indicate a mail loop'],
-            ['554', '5.6.0', 'message exceeded 50 hops, this may indicate a mail loop'],
+            ['554', '5.4.6', 'message exceeded 50 hops'],
+            ['554', '5.6.0', 'message exceeded 50 hops'],
         ],
         'norelaying' => [
             # - 550 5.7.0 Mail relay denied <ip-address>. Invalid credentials for relay for one of
@@ -222,37 +231,37 @@ sub get {
             #   to our servers. Use the SMTP relay at your service provider instead. For more
             #   information, go to 'The IP you're using to send email is not authorized...'. 
             # - https://support.google.com/mail/?p=NotAuthorizedError
-            ['550', '5.7.1', "the ip you're using to send mail is not authorized to send email directly to our servers"],
+            ['550', '5.7.1', 'is not authorized to send email directly to our servers'],
         ],
         'notcompliantrfc' => [
             # - 550 5.7.1 Messages missing a valid address in the From: header, or having no From:
             #   header, are not accepted. For more information, go to Email sender guidelines and
             #   review RFC 5322 specifications.
             # - https://support.google.com/mail/?p=RfcMessageNonCompliant
-            ['550', '5.7.1', 'messages missing a valid address in the from: header'],
-            ['550', '5.7.1', 'messages with multiple addresses in from: header are not accepted'],
+            ['550', '5.7.1', 'missing a valid address in the from: header'],
+            ['550', '5.7.1', 'multiple addresses in from: header are not accepted'],
 
             # - 550 5.7.1 This message is not RFC 5322 compliant because it has duplicate headers.
             #   To reduce the amount of spam sent to Gmail, this message has been blocked. For more
             #   information, go to Email sender guidelines and review RFC 5322 specifications.
             # - https://support.google.com/mail/?p=RfcMessageNonCompliant
-            ['550', '5.7.1', 'this message is not rfc 5322 compliant'],
+            ['550', '5.7.1', 'is not rfc 5322 compliant'],
 
             # - 550 5.7.1 Messages missing a valid Message-ID: header are not accepted. For more
             #   information, go to Email sender guidelines and review RFC 5322 specifications.
             # - https://support.google.com/mail/?p=RfcMessageNonCompliant
-            ['550', '5.7.1', 'messages missing a valid message-id: header are not accepted'],
+            ['550', '5.7.1', 'missing a valid message-id: header'],
 
             # - 550 5.7.1 The message contains a unicode character in a disallowed header.
             #   To review our message and header content guidelines, go to File types blocked in
             #   Gmail. https://support.google.com/mail/?p=BlockedMessage
-            ['550', '5.7.1', 'the message contains a unicode character in a disallowed header'],
+            ['550', '5.7.1', 'contains a unicode character in a disallowed header'],
 
             # - 550 5.7.1 Encoded-word syntax is not permitted in message header header-name. To
             #   reduce the amount of spam sent to Gmail, this message has been blocked. For more
             #   information, go to Email sender guidelines and review RFC 5322 specifications.
             # - https://support.google.com/mail/?p=RfcMessageNonCompliant
-            ['550', '5.7.1', 'encoded-word syntax is not permitted in message header'],
+            ['550', '5.7.1', 'encoded-word syntax is not permitted'],
 
             # - 553 5.1.7 The sender address address is not a valid RFC 5321 address. For more
             #   information, go to About SMTP error messages and review RFC 5321 specifications.
@@ -262,48 +271,53 @@ sub get {
             # - 554 5.6.0 Mail message is malformed. Not accepted. For more information, go to
             #   Email sender guidelines and review RFC 5322 specifications.
             # - https://support.google.com/mail/?p=RfcMessageNonCompliant
-            ['554', '5.6.0', 'mail message is malformed. not accepted'],
+            ['554', '5.6.0', 'mail message is malformed'],
         ],
         'policyviolation' => [
             # - 552 5.7.0 Our system detected an illegal attachment on your message. Please visit
             #   http://mail.google.com/support/bin/answer.py?answer=6590 to review our attachment
             #   guidelines.
-            ['552', '5.7.0', 'detected an illegal attachment on your message'],
+            ['552', '5.7.0', 'illegal attachment on your message'],
 
             # - 552 5.7.0 This message was blocked because its content presents a potential securi-
             #   ty issue. Please visit https://support.google.com/mail/?p=BlockedMessage to review
             #   our message content and attachment content guidelines.
-            ['552', '5.7.0', 'this message was blocked because its content presents a potential security issue'],
+            ['552', '5.7.0', 'blocked because its content presents a potential security issue'],
 
             # - 550 5.7.1 The user or domain that you are sending to (or from) has a policy that
             #   prohibited the mail that you sent. Please contact your domain administrator for
             #   further details.
             #   For more information, visit https://support.google.com/a/answer/172179
-            ['550', '5.7.1', 'the user or domain that you are sending to (or from) has a policy that prohibited'],
+            ['550', '5.7.1', 'you are sending to (or from) has a policy that prohibited'],
 
             # - 421 4.7.28 Gmail has detected this message exceeded its quota for sending messages
             #   with the same Message-ID:. To best protect our users, the message has been tempo-
             #   rarily rejected. For more information, go to Why has Gmail blocked my messages?.
             #   https://support.google.com/mail/answer/188131
-            ['421', '4.7.28', 'has detected this message exceeded its quota for sending messages with the same message-id:'],
+            ['421', '4.7.28', 'sending messages with the same message-id:'],
         ],
         'rejected' => [
             # - 550 5.7.0, Mail Sending denied. This error occurs if the sender account is disabled
             #   or not registered within your Google Workspace domain.
             # - https://support.google.com/a/answer/6140680#maildenied
             ['550', '5.7.0', 'mail sending denied'],
-            ['550', '5.7.1', 'unauthenticated email is not accepted from this domain'],
+            ['550', '5.7.1', 'unauthenticated email is not accepted'],
         ],
         'requireptr' => [
-            # - 550 5.7.1 This message does not meet IPv6 sending guidelines regarding PTR records
-            #   and authentication. For more information, go to Email sender guidelines.
-            #   https://support.google.com/mail/?p=IPv6AuthError
-            ['550', '5.7.1', 'this message does not meet ipv6 sending guidelines regarding ptr records and authentication'],
-
             # - 421 4.7.0 The IP address sending this message does not have a PTR record, or the
             #   corresponding forward DNS entry does not point to the sending IP. To protect our
             #   users from spam, mail sent from your IP address has been temporarily rate limited.
             #   For more information, go to Email sender guidelines.
+            ['421', '4.7.0',  'does not have a ptr record'],
+
+            # - 421 4.7.23 The sending IP address for this message doesn't have a PTR record, or
+            #   the PTR record's forward DNS entry doesn't match the sending IP address. To protect
+            #   users from spam, your email has been temporarily rate limited.
+            ['421', '4.7.23', ' have a ptr record, or the ptr record'],
+
+            # - 550 5.7.1 This message does not meet IPv6 sending guidelines regarding PTR records
+            #   and authentication. For more information, go to Email sender guidelines.
+            #   https://support.google.com/mail/?p=IPv6AuthError
             #
             # - 550 5.7.25 The IP address sending this message does not have a PTR record setup, or
             #   the corresponding forward DNS entry does not point to the sending IP. As a policy,
@@ -314,9 +328,9 @@ sub get {
             # - 550 5.7.25 The sending IP does not match the IP address of the hostname specified
             #   in the pointer (PTR) record. For more information, go to Email sender guidelines.
             # - https://support.google.com/mail/answer/81126#ip-practices
-            ['421', '4.7.0',  'the ip address sending this message does not have a ptr record'],
-            ['550', '5.7.25', 'the ip address sending this message does not have a ptr record'],
-            ['550', '5.7.25', 'the sending ip does not match the ip address of the hostname'],
+            ['550', '5.7.1',  'does not meet ipv6 sending guidelines regarding ptr records and authentication'],
+            ['550', '5.7.25', 'does not have a ptr record'],
+            ['550', '5.7.25', 'does not match the ip address of the hostname'],
         ],
         'securityerror' => [
             # - 421 4.7.0 TLS required for RCPT domain, closing connection. For more information,
@@ -324,7 +338,7 @@ sub get {
             #
             # - 454 4.7.0 Too many login attempts, please try again later. For more information, go
             #   to Add Gmail to another email client. https://support.google.com/mail/answer/7126229
-            ['421', '4.7.0', 'tls required for rcpt domain, closing connection'],
+            ['421', '4.7.0', 'tls required for rcpt domain'],
             ['454', '4.7.0', 'too many login attempts'],
 
             # - 503 5.7.0 No identity changes permitted. For more information, go to About SMTP
@@ -345,32 +359,33 @@ sub get {
 
             # - 535 5.7.1 Please log in with your web browser and then try again. For more infor-
             #   mation, visit https://support.google.com/mail/bin/accounts/answer/78754
-            ['535', '5.7.1',  'please log in with your web browser and then try again'],
-            ['534', '5.7.9',  'please log in with your web browser and then try again'],
-            ['534', '5.7.14', 'please log in through your web browser and then try again'],
+            ['535', '5.7.1',  'please log in with your web browser'],
+            ['534', '5.7.9',  'please log in with your web browser'],
+            ['534', '5.7.14', 'please log in through your web browser'],
 
             # - 535 5.7.1 Username and Password not accepted. For more information, visit 
             #   https://support.google.com/accounts/troubleshooter/2402620
             ['535', '5.7.1', 'username and password not accepted'],
             ['535', '5.7.8', 'username and password not accepted'],
 
-            # - 421 4.7.29 This mail has been rate limited because TLS wasn't used. Gmail requires
-            #   all large senders to use TLS/SSL during SMTP. For instructions on using TLS, go to
-            #   TLS & SSL connections. https://support.google.com/a/answer/100181
-            ['421', '4.7.29', 'gmail requires all large senders to use tls/ssl during smtp'],
+            # - 421 4.7.29 Your email has been rate limited because this message wasn't sent over a
+            #   TLS connection. Gmail requires all bulk email senders to use TLS/SSL for SMTP conn-
+            #   ections.
+            ['421', '4.7.29', 'senders to use tls/ssl for smtp'],
+            ['550', '5.7.29', 'senders to use tls/ssl for smtp'],
         ],
         'spamdetected' => [
             # - 421 4.7.0 This message is suspicious due to the nature of the content or the links
             #   within. To best protect our users from spam, the message has been blocked. For more
             #   information, go to Why has Gmail blocked my messages?.
             #   https://support.google.com/mail/answer/188131
-            ['421', '4.7.0', 'this message is suspicious due to the nature of the content or the links within'],
+            ['421', '4.7.0', 'due to the nature of the content or the links within'],
 
             # - 550 5.7.1 Our system has detected that this message is likely unsolicited mail. To
             #   reduce the amount of spam sent to Gmail, this message has been blocked.
             #   For more information, visit https://support.google.com/mail/answer/188131
             # - https://support.google.com/mail/?p=UnsolicitedMessageError
-            ['550', '5.7.1', 'this message is likely unsolicited mail'],
+            ['550', '5.7.1', 'likely unsolicited mail'],
         ],
         'speeding' => [
             # - 450 4.2.1 The user you are trying to contact is receiving mail too quickly. Please
@@ -389,8 +404,8 @@ sub get {
             #   later time. If the user is able to receive mail at that time, your message will be
             #   delivered. For more information, visit https://support.google.com/mail/answer/6592
             # - https://support.google.com/mail/?p=ReceivingRatePerm
-            ['450', '4.2.1', 'is receiving mail at a rate that prevents additional messages from being delivered'],
-            ['550', '5.2.1', 'is receiving mail at a rate that prevents additional messages from being delivered'],
+            ['450', '4.2.1', 'rate that prevents additional messages from being delivered'],
+            ['550', '5.2.1', 'rate that prevents additional messages from being delivered'],
 
             # - 550 5.4.5 Daily SMTP relay limit exceeded for user. For more information on SMTP
             #   relay sending limits please contact your administrator or visit SMTP relay service
@@ -407,17 +422,17 @@ sub get {
         'suspend' => [
             # - 550 5.2.1 The email account that you tried to reach is inactive.
             #   For more information, go to https://support.google.com/mail/?p=DisabledUser
-            ['550', '5.2.1', 'the email account that you tried to reach is disabled'],
-            ['550', '5.2.1', 'the email account that you tried to reach is inactive'],
+            ['550', '5.2.1', 'account that you tried to reach is disabled'],
+            ['550', '5.2.1', 'account that you tried to reach is inactive'],
         ],
         'syntaxerror' => [
             # - 523 5.7.10 SMTP protocol violation, no commands allowed to pipeline after STARTTLS.
             #   For more information, go to About SMTP error messages and review RFC 3207
             #   specifications.
             ['451', '4.5.0',  'smtp protocol violation'],
-            ['454', '4.5.0',  'smtp protocol violation, no commands allowed to pipeline after starttls'],
-            ['525', '5.7.10', 'smtp protocol violation, no commands allowed to pipeline after starttls'],
-            ['535', '5.5.4',  'optional argument not permitted for that auth mode'],
+            ['454', '4.5.0',  'smtp protocol violation'],
+            ['525', '5.7.10', 'smtp protocol violation'],
+            ['535', '5.5.4',  'optional argument not permitted'],
             ['454', '5.5.1',  'starttls may not be repeated'],
 
             # - 501 5.5.2 Syntax error, cannot decode response. For more information, go to About
