@@ -1,5 +1,5 @@
 package Sisimai::SMTP::Error;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 use Sisimai::SMTP::Reply;
@@ -154,7 +154,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016-2018,2020-2022 azumakuniyuki, All rights reserved.
+Copyright (C) 2016-2018,2020-2022,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
