@@ -1,5 +1,5 @@
 package Sisimai::String;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 use Encode;
@@ -295,7 +295,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018,2019,2021-2023 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2019,2021-2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
