@@ -1,6 +1,6 @@
 package Sisimai::Time;
 use parent 'Time::Piece';
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
